@@ -3,12 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply chromatic and diatonic transposition to notes
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0200';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
 use Music::Scales qw(get_scale_notes is_scale);
-use Music::Note;
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -57,15 +56,9 @@ sub transpose {
 
     my @transposed;
 
-    if ($self->scale_name eq 'chromatic') {
-        my @pitches = map { Music::Note->new($_, 'ISO')->format('midinum') + $offset } @$notes;
-        @transposed = map { Music::Note->new($_, 'midinum')->format('ISO') } @pitches;
-    }
-    else {
-        for my $n (@$notes) {
-            my $i = first_index { $_ eq $n } @{ $self->_scale };
-            push @transposed, $i == -1 ? undef : $self->_scale->[ $i + $offset ];
-        }
+    for my $n (@$notes) {
+        my $i = first_index { $_ eq $n } @{ $self->_scale };
+        push @transposed, $i == -1 ? undef : $self->_scale->[ $i + $offset ];
     }
     print 'Transposed: ', ddc(\@transposed) if $self->verbose;
 
@@ -86,7 +79,7 @@ Music::MelodicDevice::Transposition - Apply chromatic and diatonic transposition
 
 =head1 VERSION
 
-version 0.0104
+version 0.0200
 
 =head1 SYNOPSIS
 
